@@ -15,5 +15,5 @@ function(x, digits = 4, ...)
   cat("---\n")
   cat("Signif. codes: 0 `***' 0.001 `**' 0.01 `*' 0.05 `.' 0.1 ` ' 1 \n")
   cat(" \n")
-  cat("sigma ", x$sigma)
+  cat("sigma ", x$sigma, " \n")
 }
